@@ -11,7 +11,7 @@ use pretty_env_logger::formatted_timed_builder;
 use regex::Regex;
 use serde::Deserialize;
 use structopt::StructOpt;
-use strum::{EnumIter, EnumString, EnumVariantNames, VariantNames};
+use strum::{EnumIter, EnumString, EnumVariantNames, IntoEnumIterator, VariantNames};
 use sys_info::hostname;
 use which_crate::which;
 
@@ -76,6 +76,9 @@ pub enum Step {
     Chocolatey,
     Choosenim,
     Composer,
+    Conda,
+    ConfigUpdate,
+    Containers,
     CustomCommands,
     Deno,
     Dotnet,
@@ -86,11 +89,14 @@ pub enum Step {
     Fossil,
     Gcloud,
     Gem,
+    GithubCliExtensions,
     GitRepos,
+    Go,
     Haxelib,
     GnomeShellExtensions,
     HomeManager,
     Jetpack,
+    Kakoune,
     Krew,
     Macports,
     Mas,
@@ -99,7 +105,6 @@ pub enum Step {
     Nix,
     Node,
     Opam,
-    Pacdiff,
     Pacstall,
     Pearl,
     Pipx,
@@ -125,6 +130,7 @@ pub enum Step {
     Tldr,
     Tlmgr,
     Tmux,
+    Toolbx,
     Vagrant,
     Vcpkg,
     Vim,
@@ -156,6 +162,7 @@ pub struct Windows {
     accept_all_updates: Option<bool>,
     self_rename: Option<bool>,
     open_remotes_in_new_terminal: Option<bool>,
+    enable_winget: Option<bool>,
 }
 
 #[derive(Deserialize, Default, Debug)]
@@ -517,6 +524,10 @@ impl Config {
             enabled_steps.extend(only)
         }
 
+        if enabled_steps.is_empty() {
+            enabled_steps.extend(Step::iter());
+        }
+
         let mut disabled_steps: Vec<Step> = Vec::new();
         disabled_steps.extend(&opt.disable);
         if let Some(disabled) = config_file.disable.as_ref() {
@@ -851,4 +862,14 @@ impl Config {
 
         true
     }
+
+    #[cfg(windows)]
+    pub fn enable_winget(&self) -> bool {
+        return self
+            .config_file
+            .windows
+            .as_ref()
+            .and_then(|w| w.enable_winget)
+            .unwrap_or(false);
+    }
 }
