@@ -1,18 +1,20 @@
 #![allow(unused_imports)]
 
-use crate::executor::{CommandExt, RunType};
-use crate::terminal::print_separator;
-use crate::utils::{require, PathExt};
-use crate::{error::SkipStep, execution_context::ExecutionContext};
+#[cfg(unix)]
+use std::os::unix::prelude::MetadataExt;
+use std::path::PathBuf;
+use std::process::Command;
+
 use anyhow::Result;
 use directories::BaseDirs;
 use log::debug;
 #[cfg(unix)]
 use nix::unistd::Uid;
-#[cfg(unix)]
-use std::os::unix::prelude::MetadataExt;
-use std::path::PathBuf;
-use std::process::Command;
+
+use crate::executor::{CommandExt, RunType};
+use crate::terminal::print_separator;
+use crate::utils::{require, PathExt};
+use crate::{error::SkipStep, execution_context::ExecutionContext};
 
 #[allow(clippy::upper_case_acronyms)]
 struct NPM {
@@ -27,20 +29,22 @@ impl NPM {
     #[cfg(target_os = "linux")]
     fn root(&self) -> Result<PathBuf> {
         Command::new(&self.command)
-            .args(["root", "-g"])
+            .args(&["root", "-g"])
             .check_output()
             .map(|s| PathBuf::from(s.trim()))
     }
 
     fn upgrade(&self, run_type: RunType, use_sudo: bool) -> Result<()> {
+        print_separator("Node Package Manager");
+
         if use_sudo {
             run_type
                 .execute("sudo")
                 .arg(&self.command)
-                .args(["update", "-g"])
+                .args(&["update", "-g"])
                 .check_run()?;
         } else {
-            run_type.execute(&self.command).args(["update", "-g"]).check_run()?;
+            run_type.execute(&self.command).args(&["update", "-g"]).check_run()?;
         }
 
         Ok(())
@@ -77,7 +81,6 @@ fn should_use_sudo(npm: &NPM, ctx: &ExecutionContext) -> Result<bool> {
 pub fn run_npm_upgrade(ctx: &ExecutionContext) -> Result<()> {
     let npm = require("npm").map(NPM::new)?;
 
-    print_separator("Node Package Manager");
     #[cfg(target_os = "linux")]
     {
         npm.upgrade(ctx.run_type(), should_use_sudo(&npm, ctx)?)
@@ -98,14 +101,14 @@ pub fn pnpm_global_update(ctx: &ExecutionContext) -> Result<()> {
         ctx.run_type()
             .execute("sudo")
             .arg(pnpm)
-            .args(["update", "-g"])
+            .args(&["update", "-g"])
             .check_run()
     } else {
-        ctx.run_type().execute(&pnpm).args(["update", "-g"]).check_run()
+        ctx.run_type().execute(&pnpm).args(&["update", "-g"]).check_run()
     }
 
     #[cfg(not(target_os = "linux"))]
-    ctx.run_type().execute(&pnpm).args(["update", "-g"]).check_run()
+    ctx.run_type().execute(&pnpm).args(&["update", "-g"]).check_run()
 }
 
 pub fn deno_upgrade(ctx: &ExecutionContext) -> Result<()> {
