@@ -1,3 +1,10 @@
+use std::path::{Path, PathBuf};
+use std::process::Command;
+
+use anyhow::Result;
+use ini::Ini;
+use log::{debug, warn};
+
 use crate::error::{SkipStep, TopgradeError};
 use crate::execution_context::ExecutionContext;
 use crate::executor::{CommandExt, RunType};
@@ -5,22 +12,9 @@ use crate::steps::os::archlinux;
 use crate::terminal::{print_separator, print_warning};
 use crate::utils::{require, require_option, which, PathExt};
 use crate::Step;
-use anyhow::Result;
-use ini::Ini;
-use log::{debug, warn};
-use serde::Deserialize;
-use std::path::{Path, PathBuf};
-use std::process::Command;
 
 static OS_RELEASE_PATH: &str = "/etc/os-release";
 
-#[derive(Debug, Deserialize)]
-#[serde(rename_all = "UPPERCASE")]
-struct OsRelease {
-    id_like: Option<String>,
-    id: String,
-}
-
 #[allow(clippy::upper_case_acronyms)]
 #[derive(Copy, Clone, Debug, PartialEq, Eq)]
 pub enum Distribution {
@@ -165,14 +159,10 @@ fn upgrade_alpine_linux(ctx: &ExecutionContext) -> Result<()> {
 }
 
 fn upgrade_redhat(ctx: &ExecutionContext) -> Result<()> {
-    let _ = if let Some(ostree) = Path::new("rpm-ostree").if_exists() {
+    if let Some(ostree) = which("rpm-ostree") {
         if ctx.config().rpm_ostree() {
             let mut command = ctx.run_type().execute(ostree);
             command.arg("upgrade");
-            if ctx.config().yes(Step::System) {
-                command.arg("-y");
-            }
-
             return command.check_run();
         }
     };
@@ -230,15 +220,19 @@ fn upgrade_suse(ctx: &ExecutionContext) -> Result<()> {
 
 fn upgrade_void(ctx: &ExecutionContext) -> Result<()> {
     if let Some(sudo) = ctx.sudo() {
-        ctx.run_type()
-            .execute(&sudo)
-            .args(&["xbps-install", "-Su", "xbps"])
-            .check_run()?;
+        let mut command = ctx.run_type().execute(&sudo);
+        command.args(&["xbps-install", "-Su", "xbps"]);
+        if ctx.config().yes(Step::System) {
+            command.arg("-y");
+        }
+        command.check_run()?;
 
-        ctx.run_type()
-            .execute(&sudo)
-            .args(&["xbps-install", "-u"])
-            .check_run()?;
+        let mut command = ctx.run_type().execute(&sudo);
+        command.args(&["xbps-install", "-u"]);
+        if ctx.config().yes(Step::System) {
+            command.arg("-y");
+        }
+        command.check_run()?;
     } else {
         print_warning("No sudo detected. Skipping system upgrade");
     }
@@ -331,16 +325,11 @@ fn upgrade_solus(ctx: &ExecutionContext) -> Result<()> {
 
 pub fn run_pacstall(ctx: &ExecutionContext) -> Result<()> {
     let pacstall = require("pacstall")?;
-    ctx.run_type()
-        .execute(&pacstall)
-        .arg("-U")
-        .args(ctx.config().yay_arguments().split_whitespace())
-        .check_run()?;
-    ctx.run_type()
-        .execute(pacstall)
-        .arg("-Up")
-        .args(ctx.config().yay_arguments().split_whitespace())
-        .check_run()
+
+    print_separator("Pacstall");
+
+    ctx.run_type().execute(&pacstall).arg("-U").check_run()?;
+    ctx.run_type().execute(pacstall).arg("-Up").check_run()
 }
 
 fn upgrade_clearlinux(ctx: &ExecutionContext) -> Result<()> {
@@ -543,21 +532,29 @@ pub fn run_pihole_update(sudo: Option<&PathBuf>, run_type: RunType) -> Result<()
     run_type.execute(sudo).arg(pihole).arg("-up").check_run()
 }
 
-pub fn run_etc_update(sudo: Option<&PathBuf>, run_type: RunType) -> Result<()> {
-    let sudo = require_option(sudo, String::from("sudo is not installed"))?;
-    let etc_update = require("etc-update")?;
-    print_separator("etc-update");
+pub fn run_config_update(ctx: &ExecutionContext) -> Result<()> {
+    let sudo = require_option(ctx.sudo().as_ref(), String::from("sudo is not installed"))?;
+    if ctx.config().yes(Step::ConfigUpdate) {
+        return Err(SkipStep("Skipped in --yes".to_string()).into());
+    }
 
-    run_type.execute(sudo).arg(etc_update).check_run()
-}
+    if let Ok(etc_update) = require("etc-update") {
+        print_separator("Configuration update");
+        ctx.run_type().execute(sudo).arg(etc_update).check_run()?;
+    } else if let Ok(pacdiff) = require("pacdiff") {
+        if std::env::var("DIFFPROG").is_err() {
+            require("vim")?;
+        }
 
-pub fn run_pacdiff(sudo: Option<&PathBuf>, run_type: RunType) -> Result<()> {
-    let sudo = require_option(sudo, String::from("sudo is not installed"))?;
-    let pacdiff = require("pacdiff")?;
+        print_separator("Configuration update");
+        ctx.run_type()
+            .execute(sudo)
+            .arg("--preserve-env=DIFFPROG")
+            .arg(pacdiff)
+            .check_run()?;
+    }
 
-    print_separator("pacdiff");
-
-    run_type.execute(sudo).arg(pacdiff).check_run()
+    Ok(())
 }
 
 #[cfg(test)]
